import * as angular from "angular";

export const keyPressModule = "seges.intervalpicker.directives.keyPress";

export interface IKeyPressAttributes extends ng.IAttributes {
    escapeCallback: string;
    enterCallback: string;
}

/**
 * OutsideClickDirective
 */
export class KeyPressDirective implements ng.IDirective {
    static escapeKey: number = 27;
    static enterKey: number = 13;

    restrict: string = "A";

    onEscape: ($scope: ng.IScope) => any;
    onEnter: ($scope: ng.IScope) => any;
    context: ng.IScope;

    constructor(private $parse: ng.IParseService) {}

    link = (scope: ng.IScope, element: ng.IAugmentedJQuery, attributes: IKeyPressAttributes) => {
        this.context = scope;
        this.onEnter = this.$parse(attributes.enterCallback);
        this.onEscape = this.$parse(attributes.escapeCallback);

        element.on("keydown", (event: JQueryEventObject) => this.onKeyDown(event));
        element.on("$destroy", () => element.off("keydown", this.onKeyDown));
    }

    onKeyDown = (event: JQueryEventObject) => {
        switch (event.keyCode) {
            case KeyPressDirective.enterKey:
                this.context.$apply(this.onEnter);
                break;
            case KeyPressDirective.escapeKey:
                this.context.$apply(this.onEscape);
                break;
            default:
                break;
        }
    }

}

angular
    .module(keyPressModule, [])
    .directive("intPickerKeypress", ($parse: ng.IParseService) => new KeyPressDirective($parse));
